@@ -1,7 +1,7 @@
 /**************************************************************************
  *   files.c  --  This file is part of GNU nano.                          *
  *                                                                        *
- *   Copyright (C) 1999-2011, 2013-2017 Free Software Foundation, Inc.    *
+ *   Copyright (C) 1999-2011, 2013-2018 Free Software Foundation, Inc.    *
  *   Copyright (C) 2015-2017 Benno Schulenberg                            *
  *                                                                        *
  *   GNU nano is free software: you can redistribute it and/or modify     *
@@ -345,6 +345,9 @@ int do_lockfile(const char *filename)
 		pidstring = charalloc(11);
 		sprintf (pidstring, "%u", (unsigned int)lockpid);
 
+		/* Display newlines in filenames as ^J. */
+		as_an_at = FALSE;
+
 		/* TRANSLATORS: The second %s is the name of the user, the third that of the editor. */
 		question = _("File %s is being edited (by %s with %s, PID %s); continue?");
 		room = COLS - strlenpt(question) + 7 - strlenpt(lockuser) -
@@ -359,7 +362,7 @@ int do_lockfile(const char *filename)
 			strcat(postedname, fragment);
 			free(fragment);
 		} else
-			postedname = mallocstrcpy(NULL, filename);
+			postedname = display_string(filename, 0, room, FALSE);
 
 		/* Allow extra space for username (14), program name (8), PID (8),
 		 * and terminating \0 (1), minus the %s (2) for the file name. */
@@ -435,7 +438,8 @@ bool open_buffer(const char *filename, bool undoable)
 	if (strcmp(filename, "") != 0) {
 		struct stat fileinfo;
 
-		if (stat(realname, &fileinfo) == 0 && !S_ISREG(fileinfo.st_mode)) {
+		if (stat(realname, &fileinfo) == 0 && !(S_ISREG(fileinfo.st_mode) ||
+					(ISSET(NOREAD_MODE) && S_ISFIFO(fileinfo.st_mode)))) {
 			if (S_ISDIR(fileinfo.st_mode))
 				statusline(ALERT, _("\"%s\" is a directory"), realname);
 			else
@@ -2192,12 +2196,17 @@ int do_writeout(bool exiting, bool withprompt)
 
 				if (name_exists) {
 					char *question = _("File \"%s\" exists; OVERWRITE? ");
+					char *name = display_string(answer, 0,
+										COLS - strlenpt(question) + 1, FALSE);
 					char *message = charalloc(strlen(question) +
-												strlen(answer) + 1);
-					sprintf(message, question, answer);
+												strlen(name) + 1);
+
+					sprintf(message, question, name);
 
 					i = do_yesno_prompt(FALSE, message);
+
 					free(message);
+					free(name);
 
 					if (i < 1)
 						continue;
